@@ -1,9 +1,8 @@
 import wave
 import os
-from formatConvert.wav_pcm import get_data_array
 import  numpy as np
 from moviepy.editor import AudioFileClip
-from commFunction import get_rms,get_ave_rms,get_one_channel_data,get_file_duration
+from commFunction import get_rms,get_ave_rms,get_one_channel_data,get_file_duration,get_data_array
 
 
 def get_wav_from_mp4(mp4file):
