@@ -5,7 +5,7 @@ sys.path.append('../')
 """
 @author: Gabriel Mittag, TU-Berlin
 """
-from NISQA_model import nisqaModel
+from MOS_INFER.NISQA_model import nisqaModel
 import os
 import warnings
 
@@ -33,7 +33,7 @@ def cal_mos_infer(testFile=None):
 
 
 if __name__ == "__main__":
-    test = 'test/input0(2).wav'
+    test = 'mixDstFile_minus_6.wav'
     df = cal_mos_infer(test)
     print(df)
 
