@@ -8,7 +8,7 @@ from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
 from .resample.resampler import resample,restruct
 from .timeAligment.time_align import cal_delay
-from .formatConvert.wav_pcm import get_data_array
+from .commFunction import get_data_array
 from .SNR_ESTIMATION.MATCH_SIG import match_sig
 from .SNR_ESTIMATION.SNR_MUSIC import cal_snr_music
 from .SNR_ESTIMATION.SNR_TRANSIENT import cal_snr_transient
